.. currentmodule:: pynrc

NIRCam Tools
============

.. rubric:: Functions Summary

.. autosummary::

    ~nrc_utils.read_filter
    ~nrc_utils.psf_coeff
    ~nrc_utils.wfed_coeff
    ~nrc_utils.gen_image_coeff
    ~nrc_utils.bg_sensitivity
    ~nrc_utils.sat_limit_webbpsf
    ~nrc_utils.pix_noise
    ~nrc_utils.channel_select
    ~nrc_utils.grism_res
    ~nrc_utils.build_mask
    ~nrc_utils.build_mask_detid
    ~nrc_utils.coron_trans
    ~nrc_utils.offset_bar
    ~nrc_utils.config2
    ~nrc_utils.create_detops


.. rubric:: Documentation

.. autofunction:: pynrc.nrc_utils.read_filter
.. autofunction:: pynrc.nrc_utils.psf_coeff
.. autofunction:: pynrc.nrc_utils.wfed_coeff
.. autofunction:: pynrc.nrc_utils.gen_image_coeff
.. autofunction:: pynrc.nrc_utils.bg_sensitivity
.. autofunction:: pynrc.nrc_utils.sat_limit_webbpsf
.. autofunction:: pynrc.nrc_utils.pix_noise
.. autofunction:: pynrc.nrc_utils.channel_select
.. autofunction:: pynrc.nrc_utils.grism_res
.. autofunction:: pynrc.nrc_utils.build_mask
.. autofunction:: pynrc.nrc_utils.build_mask_detid
.. autofunction:: pynrc.nrc_utils.coron_trans
.. autofunction:: pynrc.nrc_utils.offset_bar
.. autofunction:: pynrc.nrc_utils.config2
.. autofunction:: pynrc.nrc_utils.create_detops
